@@ -4,7 +4,7 @@
    :synopsis: Errata object factory.
 
 """
-from constants import VISUAL_SEPARATOR
+from esgissue.constants import VISUAL_SEPARATOR
 errata_viewer_url_base = 'https://errata.es-doc.org/static/view.html?uid='
 
 
@@ -23,8 +23,10 @@ class ErrataObject(object):
         self.is_latest = False
         self.is_queried = False
         self.is_first = False
+        self.errata_ids_list = None
         self._check_for_multiple_errata()
 
+
     def __str__(self):
         result_string = ''
         if self.has_errata:
@@ -41,7 +43,8 @@ class ErrataObject(object):
     def _check_for_multiple_errata(self):
         # Checks for the case where multiple errata ids are found for a single dataset/file
         # instead of double ErrataObjects, it's taken care of in printing.
-        self.errata_ids_list = self.errata_ids.split(';')
+        if self.errata_ids_list is not None:
+            self.errata_ids_list = self.errata_ids.split(';')
 
 
 
